==> haskell-yesod-core-1.4.24-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.4.24
id: yesod-core-1.4.24-7HgcRzxpjUt8U7znc5NeaL
key: yesod-core-1.4.24-7HgcRzxpjUt8U7znc5NeaL
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Json Yesod.Core.Widget
    Yesod.Core.Internal Yesod.Core.Types Yesod.Core.Unsafe
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
abi: 063f35c24b41cb7c312ade719a7028c0
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-core-1.4.24
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-core-1.4.24
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-core-1.4.24
hs-libraries: HSyesod-core-1.4.24-7HgcRzxpjUt8U7znc5NeaL
depends:
    aeson-0.11.2.0-BJFBIG7cfak4WE0j2VGFvV
    auto-update-0.1.4-GAesfFmqoZzBz6e09kRyzb base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.2-2ceCZ3Fm7x67ZwaaR7uQ3C
    blaze-markup-0.7.1.0-BKRb0wHFpEyDJWTsyjQqnp
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
    cereal-0.5.3.0-JHJQkHEuvBGFx8XwIB7eX0
    clientsession-0.9.1.2-JZNK9Gu1Abu4M40ju0v5ct
    conduit-1.2.7-1fFSFiPEs5YE08sG4lN9Z3
    conduit-extra-1.1.13.2-CPtzSyRlb4w7sgNGBWFen3 containers-0.5.7.1
    cookie-0.4.2.1-DnnDAS5t2oj6QKbT9Eh839
    data-default-0.7.1.1-IrbTxn4APE83ZiDGILskO deepseq-1.4.2.0
    deepseq-generics-0.2.0.0-ESBROgKchbm3QXcQv2e7oG directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    fast-logger-2.4.6-Ko6hpzrohxlG6RfUnE9VNU
    http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.19-6JmMEWCmPWS8OjfXPvSLiG
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    random-1.1-54KmMHXjttlERYcr1mvsAe
    resourcet-1.1.7.5-3j9hqcrUWUtEP6gwxkGxax
    safe-0.3.9-Hqo3JhJes6h6KTrVZw55Pb
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    shakespeare-2.0.11.1-K5hToLGQH3j3Bo2NBPWz04
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unix-compat-0.4.2.0-GNHotEMWE5dJ4oYFhgibIV
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    wai-3.2.1.1-3kBgN7EuSbyJsj8pT2dpLl
    wai-extra-3.0.16.1-AZOxxbGpL442ae7hLE7VHT
    wai-logger-2.3.0-AwchvAw6Nh2qDWAbQxKeO
    warp-3.2.8-28jbIHyHHpkF5iLlptGYdT
    word8-0.1.2-2E1SgvvAV2fK8vZPDHbRan
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-core-1.4.24-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-core
version: 1.4.24
id: yesod-core-1.4.24-HZGqn5CVC5sHb7hje5QEqf
key: yesod-core-1.4.24-HZGqn5CVC5sHb7hje5QEqf
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Creation of type-safe, RESTful web applications.
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-core>
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Core Yesod.Core.Content Yesod.Core.Dispatch
    Yesod.Core.Handler Yesod.Core.Json Yesod.Core.Widget
    Yesod.Core.Internal Yesod.Core.Types Yesod.Core.Unsafe
    Yesod.Routes.TH.Types
hidden-modules: Yesod.Core.Internal.Session
                Yesod.Core.Internal.Request Yesod.Core.Class.Handler
                Yesod.Core.Internal.Util Yesod.Core.Internal.Response
                Yesod.Core.Internal.Run Yesod.Core.Internal.TH
                Yesod.Core.Internal.LiteApp Yesod.Core.Class.Yesod
                Yesod.Core.Class.Dispatch Yesod.Core.Class.Breadcrumbs
                Yesod.Core.TypeCache Paths_yesod_core Yesod.Routes.TH
                Yesod.Routes.Class Yesod.Routes.Parse Yesod.Routes.Overlap
                Yesod.Routes.TH.Dispatch Yesod.Routes.TH.RenderRoute
                Yesod.Routes.TH.ParseRoute Yesod.Routes.TH.RouteAttrs
abi: 3c735dd1a85dec4b6d93f4af763b91e7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-core-1.4.24
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-core-1.4.24
data-dir: /usr/share/arm-linux-ghc-8.0.1/yesod-core-1.4.24
hs-libraries: HSyesod-core-1.4.24-HZGqn5CVC5sHb7hje5QEqf
depends:
    aeson-0.11.2.0-1oWMNtvIfKMGa0C5QxOdH8
    auto-update-0.1.4-GAesfFmqoZzBz6e09kRyzb base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.2-2ceCZ3Fm7x67ZwaaR7uQ3C
    blaze-markup-0.7.1.0-BKRb0wHFpEyDJWTsyjQqnp
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    case-insensitive-1.2.0.7-EiN1BqaYOWgBoqFOLWTmWz
    cereal-0.5.3.0-JHJQkHEuvBGFx8XwIB7eX0
    clientsession-0.9.1.2-JZNK9Gu1Abu4M40ju0v5ct
    conduit-1.2.7-1fFSFiPEs5YE08sG4lN9Z3
    conduit-extra-1.1.13.2-CPtzSyRlb4w7sgNGBWFen3 containers-0.5.7.1
    cookie-0.4.2.1-DnnDAS5t2oj6QKbT9Eh839
    data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr deepseq-1.4.2.0
    deepseq-generics-0.2.0.0-ESBROgKchbm3QXcQv2e7oG directory-1.2.6.2
    exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    fast-logger-2.4.6-9GBt3oT9uhPEFmGPkG5aqd
    http-types-0.9.1-58mzFhAgNAb9DH0XYXjd5P
    lifted-base-0.2.3.8-49pRtI70Gt75UpVUvp7oxA
    monad-control-1.0.1.0-CVvkY5Vr2NNGCNJRXug3iR
    monad-logger-0.3.19-LrQppJRg01vCMSgTEsQBGO
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    mwc-random-0.13.4.0-CH6ozsPFZjwVSNwmEz44J
    old-locale-1.0.0.7-6glXNhHF891B41ZfuI8hU8
    parsec-3.1.11-IYEP8Lv1S9x5FeUQxGPDBY
    path-pieces-0.2.1-EkkcipvGNTB6jNvz5dfdoN
    primitive-0.6.1.0-Ip44DqhfCp21tTUYbecwa
    random-1.1-54KmMHXjttlERYcr1mvsAe
    resourcet-1.1.7.5-3j9hqcrUWUtEP6gwxkGxax
    safe-0.3.9-Hqo3JhJes6h6KTrVZw55Pb
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    shakespeare-2.0.11.1-3SyyZoWFAdPC9dHlPUb5aq
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
    unix-compat-0.4.2.0-GNHotEMWE5dJ4oYFhgibIV
    unordered-containers-0.2.7.1-6Q3w38ZivLTB9nLFgf8RUI
    vector-0.11.0.0-BEDZb5o2QOhGbIm6ky7rl6
    wai-3.2.1.1-3kBgN7EuSbyJsj8pT2dpLl
    wai-extra-3.0.17-LIUQJ8BzBbkJOkYQN1gqKa
    wai-logger-2.3.0-Cwv5Fo0K1fH5RN4I46XB2L
    warp-3.2.8-28jbIHyHHpkF5iLlptGYdT
    word8-0.1.2-2E1SgvvAV2fK8vZPDHbRan
haddock-interfaces: /usr/share/doc/haskell-yesod-core/html/yesod-core.haddock
haddock-html: /usr/share/doc/haskell-yesod-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
